@@ -8,6 +8,8 @@ This module is Copyright (C) 2017 by
 
 Jim Turner, C<< <turnerjw784 at yahoo.com> >>
 		
+Email: turnerjw784@yahoo.com
+
 All rights reserved.
 
 You may distribute this module under the terms of either the GNU General 
@@ -34,7 +36,9 @@ file.
 
 	my $besturl = $station->getBest('Url');
 
-	print "Best stream URL=$besturl\n";
+	my $stationTitle = $station->getStationTitle();
+	
+	print "Best stream URL=$besturl, Title=$stationTitle\n";
 
 	my @allfields = $station->validFields();
 
@@ -78,8 +82,6 @@ use strict;
 
 	my $besturl = $kluv->getBest('Url');
 
-	print "Best stream URL=$besturl\n";  #RETURNS:  "http://19273.live.streamtheworld.com/KLUVFM_SC"
-
 	my $beststream = $kluv->getBest();
 
 	my @allfields = $kluv->validFields();
@@ -146,6 +148,25 @@ B<StreamId>, B<Type>, B<Url>).  These can be used in the I<get> functions and
 as the keys in the hash references returned to fetch the corresponding 
 property values.
 
+=item $station->B<getStationID>()
+
+Returns the station's Tunein ID, for eample, the station: 
+'http://tunein.com/radio/987-KLUV-s33892/' would return "s33892".
+
+=item $station->B<getStationTitle>()
+
+Returns the station's title (description).  for eample, the station:
+'http://tunein.com/radio/987-KLUV-s33892/' would return:
+"KLUV - Dallas, TX - Listen Online".
+
+=item $station->B<getIconURL>()
+
+Returns the url for the station's "cover art" icon image.
+
+=item $station->B<getImageURL>()
+
+Returns the url for the station's Tunein site's banner image.
+
 =back
 
 =head1 KEYWORDS
@@ -168,7 +189,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Tunein::Streams
 
-
 You can also look for information at:
 
 =over 4
@@ -247,7 +267,7 @@ use warnings;
 use LWP::Simple qw();
 use vars qw(@ISA @EXPORT $VERSION);
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 require Exporter;
 
@@ -286,6 +306,10 @@ sub new
 	my (@streams, @streamHash, $s, $html2);
 	$self->{'cnt'} = 0;
 	$self->{'total'} = '0';
+	$self->{'id'} = ($url =~ m#([\w\d]+)\/?$#) ? $1 : $url;
+	$self->{'title'} = ($html =~ m#\<title\>(.+?)\<\/title\>#) ? $1 : '';
+	$self->{'iconurl'} = ($html =~ m#\<meta\s+property\s*\=\s*\"og\:image\"\s+content\s*\=\"([^\"]+)#) ? $1 : '';
+	$self->{'imageurl'} = ($html =~ m#\"hero\"\s+id=\s*\"imgSrc\"\s+style\=\"background\-image\:\s+url\(([^\)]+)\)#) ? $1 : '';
 	while ($html =~ s/StreamUrl\"\:\s*\"([^\"]+)\"(\,\s*\"DirectStreams\"\:\s*\[([^\]]+)\])?//o) {  #FIND ONE (OR MORE) STREAM URLS:
 		$s = $1;
 		if ($2) {   #WE HAVE A DIRECT STREAM (EMBEDDED TREE), USE THAT:
@@ -312,13 +336,13 @@ sub new
 		$self->{'total'} += scalar @{$streamHash[$self->{'cnt'}]->{'Streams'}};
 		++$self->{'cnt'};   #NUMBER OF StreamUrl's FOUND (NOT SAME AS # OF STREAMS!)
 	}
-	$self->{streams} = \@streamHash;
+	$self->{'streams'} = \@streamHash;
 	return undef  unless ($self->{'cnt'});   #STEP 2 FAILED - NO PLAYABLE STREAMS FOUND, PUNT!
 
 	#SAVE WHAT PROPERTY NAMES WE HAVE (FOR $station->validFields()):
 	
 	@{$self->{fields}} = ();
-	foreach my $field (sort keys %{${$self->{streams}}[0]->{'Streams'}[0]}) {
+	foreach my $field (sort keys %{${$self->{'streams'}}[0]->{'Streams'}[0]}) {
 		push @{$self->{fields}}, $field;
 	}
 
@@ -335,21 +359,21 @@ sub get
 	my @streams = ();
 	my $subcnt;
 	if ($field) {  #USER SUPPLIED A PROPERTY NAME, FETCH ONLY THAT PROPERTY, (ie. "Url"):
-		return ${$self->{streams}}[0]->{'Streams'}[0]->{$field}  unless (wantarray);  #USER ONLY WANTS 1ST STREAM.
+		return ${$self->{'streams'}}[0]->{'Streams'}[0]->{$field}  unless (wantarray);  #USER ONLY WANTS 1ST STREAM.
 		for (my $i=0; $i<$self->{'cnt'}; $i++) {
 			no strict;
-			$subcnt = scalar @{${$self->{streams}}[$i]->{'Streams'}};
+			$subcnt = scalar @{${$self->{'streams'}}[$i]->{'Streams'}};
 			for (my $j=0; $j<$subcnt; $j++) {
-				push @streams, ${$self->{streams}}[$i]->{'Streams'}[$j]->{$field};
+				push @streams, ${$self->{'streams'}}[$i]->{'Streams'}[$j]->{$field};
 			}
 		}
 	} else {       #NO PROPERTY NAME, RETURN A HASH-REF TO ALL THE PROPERTIES:
-		return ${$self->{streams}}[0]->{'Streams'}[0]  unless (wantarray);  #USER ONLY WANTS 1ST STREAM.
+		return ${$self->{'streams'}}[0]->{'Streams'}[0]  unless (wantarray);  #USER ONLY WANTS 1ST STREAM.
 		for (my $i=0; $i<$self->{'cnt'}; $i++) {
 			no strict;
-			$subcnt = scalar @{${$self->{streams}}[$i]->{'Streams'}};
+			$subcnt = scalar @{${$self->{'streams'}}[$i]->{'Streams'}};
 			for (my $j=0; $j<$subcnt; $j++) {
-				push @streams, ${$self->{streams}}[$i]->{'Streams'}[$j];
+				push @streams, ${$self->{'streams'}}[$i]->{'Streams'}[$j];
 			}
 		}
 	}
@@ -367,13 +391,13 @@ sub getBest   #LIKE GET, BUT ONLY RETURN THE SINGLE ONE W/BEST BANDWIDTH AND REL
 	my $ReliableBandwidth;
 	for (my $i=0; $i<$self->{'cnt'}; $i++) {
 		no strict;
-		$subcnt = scalar @{${$self->{streams}}[$i]->{'Streams'}};
+		$subcnt = scalar @{${$self->{'streams'}}[$i]->{'Streams'}};
 		for (my $j=0; $j<$subcnt; $j++) {
-			$ReliableBandwidth = (${$self->{streams}}[$i]->{'Streams'}[$j]->{'Bandwidth'} * 1000)
-					+ ${$self->{streams}}[$i]->{'Streams'}[$j]->{'Reliability'};
+			$ReliableBandwidth = (${$self->{'streams'}}[$i]->{'Streams'}[$j]->{'Bandwidth'} * 1000)
+					+ ${$self->{'streams'}}[$i]->{'Streams'}[$j]->{'Reliability'};
 			if ($ReliableBandwidth > $bestReliableBandwidth) {
-				$bestStream = $field ? ${$self->{streams}}[$i]->{'Streams'}[$j]->{$field}
-						: ${$self->{streams}}[$i]->{'Streams'}[$j];
+				$bestStream = $field ? ${$self->{'streams'}}[$i]->{'Streams'}[$j]->{$field}
+						: ${$self->{'streams'}}[$i]->{'Streams'}[$j];
 				$bestReliableBandwidth = $ReliableBandwidth;
 			}
 		}
@@ -390,7 +414,31 @@ sub count
 sub validFields
 {
 	my $self = shift;
-	return @{$self->{fields}};  #LIST OF ALL VALID PROPERTY NAME FIELDS.
+	return @{$self->{'fields'}};  #LIST OF ALL VALID PROPERTY NAME FIELDS.
+}
+
+sub getStationID
+{
+	my $self = shift;
+	return $self->{'id'};  #URL TO THE STATION'S THUMBNAIL ICON, IF ANY.
+}
+
+sub getStationTitle
+{
+	my $self = shift;
+	return $self->{'title'};  #URL TO THE STATION'S TITLE(DESCRIPTION), IF ANY.
+}
+
+sub getIconURL
+{
+	my $self = shift;
+	return $self->{'iconurl'};  #URL TO THE STATION'S THUMBNAIL ICON, IF ANY.
+}
+
+sub getImageURL
+{
+	my $self = shift;
+	return $self->{'imageurl'};  #URL TO THE STATION'S BANNER IMAGE, IF ANY.
 }
 
 1
